Documentation
¶
Index ¶
- func ClearCache()
- func ComputeGitRepo(startPath string) (map[string]string, string, error)
- func GetFilesGitStatus(p string) map[string]string
- func GetFormattedSize(b int64, humanReadable bool) string
- func GetHardLinkCount(absPath string) uint64
- func GetIcon(name, ext, indicator string) *icons.IconInfo
- func GetIndicator(name string, isLongMode bool) (i string)
- func GetInodeNumber(path string) string
- func GetModeExtended(fi *os.FileInfo, fullPath string) string
- func GetOpenDirIcon() *icons.IconInfo
- func GetSymlinkIndicator(name string, isLongMode bool) string
- func IsLink(name string) bool
- func MainSort(a, b string) bool
- func SetLessFunction(d *model.Directory, sortMode model.SortMode)
- type DefaultFormatter
- type ExtendedFormatter
- type Timestamp
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeGitRepo ¶
ComputeGitRepo ensures we have the git status map cached for the repository containing startPath. Returns a map of [absolute path -> status code] for all files in the repo, including directories, together with the repo root path and an error if not in a git repo or if 'git' fails.
func GetFilesGitStatus ¶
Returns a map of "relative path -> single-letter code" specifically under directory p adding the directory markers for each subdirectory.
func GetFormattedSize ¶
func GetHardLinkCount ¶
func GetIndicator ¶
get indicator of the file
func GetInodeNumber ¶
func GetOpenDirIcon ¶
func GetSymlinkIndicator ¶
Types ¶
type DefaultFormatter ¶
type DefaultFormatter struct{}
type ExtendedFormatter ¶
type ExtendedFormatter struct{}
Click to show internal directories.
Click to hide internal directories.